git: ca0cff79320d - main - Revert "release: Ship firmware from kmods repo on DVD"

Colin Percival <[email protected]>
Newsgroups gmane.os.freebsd.devel.cvs.src
Message-ID <6a75ff5b.1ef98.2a02429__2804.12558220036$1786117996$gmane$org@gitrepo.freebsd.org>
The branch main has been updated by cperciva:

URL: https://cgit.FreeBSD.org/src/commit/?id=ca0cff79320d49d3f10bd3aa3c472fa450a5c494

commit ca0cff79320d49d3f10bd3aa3c472fa450a5c494
Author:     Colin Percival <[email protected]>
AuthorDate: 2026-08-07 15:49:49 +0000
Commit:     Colin Percival <[email protected]>
CommitDate: 2026-08-07 15:52:39 +0000

    Revert "release: Ship firmware from kmods repo on DVD"
    
    This was a good idea, but we don't build metapackages in the kmods
    repo so it ends up breaking the release build.  I might resurrect this
    change if/when the kmods repo includes the wifi-firmware-kmod
    metapackage.
    
    This reverts commit bda8028146694ee490543b35e3349e060936fde4.
    
    MFC after:      1 second
---
 release/pkg_repos/release-dvd.conf |  7 -------
 release/scripts/pkg-stage.sh       | 25 +++++++------------------
 2 files changed, 7 insertions(+), 25 deletions(-)

diff --git a/release/pkg_repos/release-dvd.conf b/release/pkg_repos/release-dvd.conf
index d2db295c53c8..c2e64c43a56f 100644
--- a/release/pkg_repos/release-dvd.conf
+++ b/release/pkg_repos/release-dvd.conf
@@ -5,10 +5,3 @@ release: {
   fingerprints: "/usr/share/keys/pkg",
   enabled: yes
 }
-release-kmods: {
-  url: "pkg+http://pkg.FreeBSD.org/${ABI}/kmods_latest",
-  mirror_type: "srv",
-  signature_type: "fingerprints",
-  fingerprints: "/usr/share/keys/pkg",
-  enabled: yes
-}
diff --git a/release/scripts/pkg-stage.sh b/release/scripts/pkg-stage.sh
index 278f7422894d..f20ad64f8580 100755
--- a/release/scripts/pkg-stage.sh
+++ b/release/scripts/pkg-stage.sh
@@ -11,7 +11,7 @@ export REPO_AUTOUPDATE="NO"
 export ROOTDIR="$PWD/dvd"
 export PORTSDIR="${PORTSDIR:-/usr/ports}"
 
-_DVD_PACKAGES_MAIN="
+_DVD_PACKAGES="
 comms/usbmuxd
 devel/git@lite
 editors/emacs@nox
@@ -21,6 +21,7 @@ filesystems/ntfs
 misc/freebsd-doc-all
 net/mpd5
 net/rsync
+net/wifi-firmware-kmod@release
 ports-mgmt/pkg
 shells/bash
 shells/zsh
@@ -36,10 +37,6 @@ x11/xorg
 x11-wm/sway
 "
 
-_DVD_PACKAGES_KMODS="
-net/wifi-firmware-kmod@release
-"
-
 # If NOPORTS is set for the release, do not attempt to build pkg(8).
 if [ ! -f ${PORTSDIR}/Makefile ]; then
 	echo "*** ${PORTSDIR} is missing!    ***"
@@ -79,25 +76,18 @@ if [ -n "${PKG_ALTABI}" ]; then
 	ln -nfs ${PKG_ABI} ${ROOTDIR}/packages/${PKG_ALTABI}
 fi
 
 # Ensure the ports listed in _DVD_PACKAGES_* exist to sanitize the
 # final list.
-for _P in ${_DVD_PACKAGES_MAIN}; do
-	if [ -d "${PORTSDIR}/${_P%%@*}" ]; then
-		DVD_PACKAGES_MAIN="${DVD_PACKAGES_MAIN} ${_P}"
-	else
-		echo "*** Skipping nonexistent port: ${_P%%@*}"
-	fi
-done
-for _P in ${_DVD_PACKAGES_KMODS}; do
+for _P in ${_DVD_PACKAGES}; do
 	if [ -d "${PORTSDIR}/${_P%%@*}" ]; then
-		DVD_PACKAGES_KMODS="${DVD_PACKAGES_KMODS} ${_P}"
+		DVD_PACKAGES="${DVD_PACKAGES} ${_P}"
 	else
 		echo "*** Skipping nonexistent port: ${_P%%@*}"
 	fi
 done
 
 # Make sure the package list is not empty.
-if [ -z "${DVD_PACKAGES_MAIN}${DVD_PACKAGES_KMODS}" ]; then
+if [ -z "${DVD_PACKAGES}" ]; then
 	echo "*** The package list is empty."
 	echo "*** Something is very wrong."
 	# Exit '0' so the rest of the build process continues
@@ -108,8 +98,7 @@ fi
 # Print pkg(8) information to make debugging easier.
 ${PKGCMD} -vv
 ${PKGCMD} update -f
-${PKGCMD} fetch -o ${PKG_REPODIR} -r release -d ${DVD_PACKAGES_MAIN}
-${PKGCMD} fetch -o ${PKG_REPODIR} -r release-kmods -d ${DVD_PACKAGES_KMODS}
+${PKGCMD} fetch -o ${PKG_REPODIR} -d ${DVD_PACKAGES}
 
 # Create the 'Latest/pkg.pkg' symlink so 'pkg bootstrap' works
 # using the on-disc packages.
@@ -79,25 +76,18 @@ if [ -n "${PKG_ALTABI}" ]; then
 fi
 
-# Ensure the ports listed in _DVD_PACKAGES_* exist to sanitize the
+# Ensure the ports listed in _DVD_PACKAGES exist to sanitize the
 # final list.
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.